package com.xy.service;

import com.xy.entity.SysCodeConfigure;
import com.xy.mapper.SysCodeConfigureMapper;
import com.xy.service.SysCodeConfigureService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.xy.utils.*;
import org.springframework.stereotype.Service;
import io.swagger.annotations.Api;
import lombok.AllArgsConstructor;

import java.time.LocalDateTime;
import java.util.List;

import com.xy.dto.SysCodeConfigureDto;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.PostMapping;
import io.swagger.annotations.ApiOperation;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springframework.validation.annotation.Validated;
import sun.rmi.runtime.Log;

import static com.xy.utils.Beans.copy;
import static com.xy.utils.PlusBeans.toIPage;
import static com.xy.utils.PlusBeans.toPageBean;


/**
 * <p>
 * 系统编码配置表 服务实现类
 * </p>
 *
 * @author lijin
 * @since 2023-04-20
 */
@Service
@AllArgsConstructor
@Api(tags = "系统编码配置表")
public class SysCodeConfigureServiceImpl extends ServiceImpl<SysCodeConfigureMapper, SysCodeConfigure> implements SysCodeConfigureService {

    @PostMapping("obj")
    @ApiOperation("对象查询")
    public R<SysCodeConfigureDto.Vo> obj(@RequestBody SysCodeConfigureDto.Vo vo) {
        SysCodeConfigureDto.SelectList selectList = copy(SysCodeConfigureDto.SelectList.class, vo);
        List<SysCodeConfigureDto.Vo> list = list(selectList).getData();
        if (Emptys.check(list)) {
            return R.ok(list.get(0));
        }
        return R.ok();
    }

    @PostMapping("list")
    @ApiOperation("集合查询")
    public R<List<SysCodeConfigureDto.Vo>> list(@RequestBody SysCodeConfigureDto.SelectList selectList) {
        LambdaQueryWrapper<SysCodeConfigure> lambdaQueryWrapper = new MybatisPlusQuery().eqWrapper(selectList, SysCodeConfigure.class)
                .in(SysCodeConfigure::getCode, selectList.getCodes())
                .build();
        List<SysCodeConfigure> list = list(lambdaQueryWrapper);
        return R.ok(copy(SysCodeConfigureDto.Vo.class, list));
    }

    @PostMapping("page")
    @ApiOperation("分页查询")
    public R<PageBean<SysCodeConfigureDto.Vo>> page(@RequestBody SysCodeConfigureDto.Page page) {
        PageBean pageBean = page.getPage();
        LambdaQueryWrapper<SysCodeConfigure> lambdaQueryWrapper = new MybatisPlusQuery().eqWrapper(page, SysCodeConfigure.class).build();
        IPage<SysCodeConfigure> iPage = page(toIPage(pageBean), lambdaQueryWrapper);
        return R.ok(toPageBean(SysCodeConfigureDto.Vo.class, iPage));
    }

    @PostMapping("save")
    @ApiOperation("添加")
    public R save(@RequestBody @Validated SysCodeConfigureDto.Save save) {
        SysCodeConfigure sysCodeConfigure = getById(save.getCode());
        if (sysCodeConfigure != null) {
            return R.fail("编码已存在");
        }
        SysCodeConfigure saveInfo = copy(SysCodeConfigure.class, save)
                .createUserTime(AuthorizeUtils.getLoginId(Long.class));
        save(saveInfo);
        return R.ok();
    }

    @PostMapping("update")
    @ApiOperation("修改")
    public R update(@RequestBody @Validated SysCodeConfigureDto.Update update) {
        SysCodeConfigure updateInfo = copy(SysCodeConfigure.class, update)
                .updateUserTime(AuthorizeUtils.getLoginId(Long.class));
        updateById(updateInfo);
        return R.ok();
    }
}